@@ -1,5 +1,5 @@
 package Selenium::Screenshot;
-$Selenium::Screenshot::VERSION = '0.07';
+$Selenium::Screenshot::VERSION = '0.08';
 # ABSTRACT: Compare and contrast Webdriver screenshots in PNG format
 use Moo;
 use Image::Compare;
@@ -426,7 +426,7 @@ Selenium::Screenshot - Compare and contrast Webdriver screenshots in PNG format
 
 =head1 VERSION
 
-version 0.07
+version 0.08
 
 =head1 SYNOPSIS
 
@@ -760,6 +760,12 @@ feature.
 
 Daniel Gempesaw <gempesaw@gmail.com>
 
+=head1 CONTRIBUTOR
+
+=for stopwords Nicolas Georges
+
+Nicolas Georges <xlat@cpan.org>
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2015 by Daniel Gempesaw.
